@@ -93,6 +93,7 @@ use geojson::Feature;
 use rcore::Age;
 use rcore::ProductsSelection;
 use rcore::RemarkAssociation;
+use rcore::StationBoardResponse;
 use serde_json::Value;
 use std::collections::HashMap;
 
@@ -126,6 +127,7 @@ use crate::parse::operator::*;
 use crate::parse::polyline::*;
 use crate::parse::products::*;
 use crate::parse::remark::*;
+use crate::parse::station_board_response::*;
 use crate::parse::stopover::*;
 
 pub trait Profile: Send + Sync {
@@ -241,6 +243,9 @@ pub trait Profile: Send + Sync {
     ) -> ParseResult<Option<Leg>> {
         default_parse_leg(self, data, common, date)
     }
+    fn parse_leg_jny(&self, data: HafasLegJny, common: &CommonData) -> ParseResult<Leg> {
+        default_parse_leg_jny(self, data, common)
+    }
     fn parse_journeys_response(
         &self,
         data: HafasJourneysResponse,
@@ -248,6 +253,12 @@ pub trait Profile: Send + Sync {
     ) -> ParseResult<JourneysResponse> {
         default_parse_journeys_response(self, data, tariff_class)
     }
+    fn parse_station_board_response(
+        &self,
+        data: HafasStationBoardResponse,
+    ) -> ParseResult<StationBoardResponse> {
+        default_parse_station_board_response(self, data)
+    }
     fn parse_date(
         &self,
         time: Option<String>,
